@@ -116,15 +116,18 @@
  *                         Tx Enabled             bool
  *                         Transmitting           bool
  *                         Decoding               bool
- *                         Rx DF                  qint32
- *                         Tx DF                  qint32
+ *                         Rx DF                  quint32
+ *                         Tx DF                  quint32
  *                         DE call                utf8
  *                         DE grid                utf8
  *                         DX grid                utf8
  *                         Tx Watchdog            bool
  *                         Sub-mode               utf8
  *                         Fast mode              bool
- *                         Special operation mode quint8
+ *                         Special Operation Mode quint8
+ *                         Frequency Tolerance    quint32
+ *                         T/R Period             quint32
+ *                         Configuration Name     utf8
  *
  *    WSJT-X  sends this  status message  when various  internal state
  *    changes to allow the server to  track the relevant state of each
@@ -133,19 +136,22 @@
  *
  *      Application start up,
  *      "Enable Tx" button status changes,
- *      Dial frequency changes,
- *      Changes to the "DX Call" field,
- *      Operating mode, sub-mode or fast mode changes,
- *      Transmit mode changed (in dual JT9+JT65 mode),
- *      Changes to the "Rpt" spinner,
- *      After an old decodes replay sequence (see Replay below),
- *      When switching between Tx and Rx mode,
- *      At the start and end of decoding,
- *      When the Rx DF changes,
- *      When the Tx DF changes,
- *      When settings are exited,
- *      When the DX call or grid changes,
- *      When the Tx watchdog is set or reset.
+ *      dial frequency changes,
+ *      changes to the "DX Call" field,
+ *      operating mode, sub-mode or fast mode changes,
+ *      transmit mode changed (in dual JT9+JT65 mode),
+ *      changes to the "Rpt" spinner,
+ *      after an old decodes replay sequence (see Replay below),
+ *      when switching between Tx and Rx mode,
+ *      at the start and end of decoding,
+ *      when the Rx DF changes,
+ *      when the Tx DF changes,
+ *      when settings are exited,
+ *      when the DX call or grid changes,
+ *      when the Tx watchdog is set or reset,
+ *      when the frequency tolerance is changed,
+ *      when the T/R period is changed,
+ *      when the configuration name changes.
  *
  *    The Special operation mode is  an enumeration that indicates the
  *    setting  selected  in  the  WSJT-X  "Settings->Advanced->Special
@@ -159,6 +165,10 @@
  *       5 -> FOX
  *       6 -> HOUND
  *
+ *    The Frequency Tolerance  and T/R period fields may  have a value
+ *    of  the maximum  quint32 value  which implies  the field  is not
+ *    applicable.
+ *
  *
  * Decode        Out       2                      quint32
  *                         Id (unique key)        utf8
@@ -186,16 +196,26 @@
  *      back a .WAV file.
  *
  *
- * Clear         Out       3                      quint32
+ * Clear         Out/In    3                      quint32
  *                         Id (unique key)        utf8
+ *                         Window                 quint8 (In only)
  *
  *      This message is  send when all prior "Decode"  messages in the
- *      "Band activity"  window have been discarded  and therefore are
+ *      "Band Activity"  window have been discarded  and therefore are
  *      no long available for actioning  with a "Reply" message. It is
  *      sent when the user erases  the "Band activity" window and when
  *      WSJT-X  closes down  normally. The  server should  discard all
  *      decode messages upon receipt of this message.
  *
+ *      It may  also be  sent to  a WSJT-X instance  in which  case it
+ *      clears one or  both of the "Band Activity"  and "Rx Frequency"
+ *      windows.  The Window  argument  can be  one  of the  following
+ *      values:
+ *
+ *         0  - clear the "Band Activity" window (default)
+ *         1  - clear the "Rx Frequency" window
+ *         2  - clear both "Band Activity" and "Rx Frequency" windows
+ *
  *
  * Reply         In        4                      quint32
  *                         Id (target unique key) utf8
@@ -261,11 +281,12 @@
  *      button.
  *
  *
- * Close         Out       6                      quint32
+ * Close         Out/In    6                      quint32
  *                         Id (unique key)        utf8
  *
- *      Close is sent by a client immediately prior to it shutting
- *      down gracefully.
+ *      Close is  sent by  a client immediately  prior to  it shutting
+ *      down gracefully. When sent by  a server it requests the target
+ *      client to close down gracefully.
  *
  *
  * Replay        In        7                      quint32
@@ -404,6 +425,35 @@
  *      the  last  instance  only  instead of  all  instances  of  the
  *      specified  call  be  highlighted  or  have  it's  highlighting
  *      cleared.
+ *
+ *
+ * SwitchConfiguration  In 14                     quint32
+ *                         Id (unique key)        utf8
+ *                         Configuration Name     utf8
+ *
+ *      The server  may send  this message at  any time.   The message
+ *      specifies the name of the  configuration to switch to. The new
+ *      configuration must exist.
+ *
+ *
+ * Configure      In       15                     quint32
+ *                         Id (unique key)        utf8
+ *                         Mode                   utf8
+ *                         Frequency Tolerance    quint32
+ *                         Submode                utf8
+ *                         Fast Mode              bool
+ *                         T/R Period             quint32
+ *                         Rx DF                  quint32
+ *                         DX Call                utf8
+ *                         DX Grid                utf8
+ *                         Generate Messages      bool
+ *
+ *      The server  may send  this message at  any time.   The message
+ *      specifies  various  configuration  options.  For  utf8  string
+ *      fields an empty value implies no change, for the quint32 Rx DF
+ *      and  Frequency  Tolerance  fields the  maximum  quint32  value
+ *      implies  no change.   Invalid or  unrecognized values  will be
+ *      silently ignored.
  */
 
 #include <QDataStream>
@@ -433,6 +483,8 @@ namespace NetworkMessage
       Location,
       LoggedADIF,
       HighlightCallsign,
+      SwitchConfiguration,
+      Configure,
       maximum_message_type_     // ONLY add new message types
                                 // immediately before here
     };
